
--hump Timer module
require("hump/timer.lua")

learnTimer = Gamestate.new()

function learnTimer:enter(previous)
  menu =
    "This is the timer module example.\n\n" ..
    
    "Escape returns to the menu.\n\n" ..
    
    "Press the corresponding number for demonstrations.\n" ..
    "1. Clear Timer functions.\n" ..
    "2. Clear Squares.\n" ..
    "3. Add a square after 1 second.\n" ..
    "4. Add a square every 1 second for only 10 seconds.\n" ..
    "5. Add a square every 1 second.\n" ..
    "6. Fade in a square.\n"
  
  --Using squares to demonstrate timer functions
  squares = {}
  function newSquare(update)
    length = math.random(150) + 50
    x = math.random(800+2*length) + 0.5 - length
    y = math.random(600+2*length) + 0.5 - length
    red = math.random(255)
    green = math.random(255)
    blue = math.random(255)
    alpha = 255
    local s = {x=x,y=y, length=length, red=red,green=green,blue=blue, alpha=alpha}
    s.update = update or function() end
    return s
  end
  
end

function learnTimer:update(dt)
  for i=#squares, 1, -1 do
    squares[i]:update(dt)
  end
  --Required for Timer module to function
  Timer.update(dt)
end

function learnTimer.draw()
  for i=#squares, 1, -1 do
    local origColor = {love.graphics.getColor()}
    local square = squares[i]
    love.graphics.setColor(square.red,square.green,square.blue, square.alpha)
    love.graphics.rectangle("line",square.x,square.y,square.length,square.length)
    love.graphics.setColor(unpack(origColor))
  end
  love.graphics.print("#squares: "..#squares.."\n\n"..menu,10,10)
end

function learnTimer:keypressed(key)
  if key=='escape' then
    Gamestate.switch(learnGamestate)
  elseif key=='1' then
    --Clears all functions in Timer
    Timer.clear()
  elseif key=='2' then
    squares = {}
  elseif key=='3' then
    --This will call the function after 1 second
    Timer.add(1, function() table.insert(squares,1,newSquare()) end)
  elseif key=='4' then
    --This will call the passed function every 1 seconds
    Timer.addPeriodic(1, function() table.insert(squares,1,newSquare()) end, 10)
  elseif key=='5' then
    --This will call the passed function every 1 seconds
    Timer.addPeriodic(1, function() table.insert(squares,1,newSquare()) end)
  elseif key=='6' then
    --This will create a square that fades in
    local fader = Interpolator(5, function(fraction) return fraction*255 end)
    table.insert(squares,1,newSquare(function(self,dt) self.alpha = fader(dt) end))
  end
end

function learnTimer:leave()
  menu = nil
  squares = nil
end
 